@@ -17,6 +17,10 @@ except ImportError:
 
 
 def get_dict_from_obj(obj):
+    '''
+    Edit to get the dict even when the object is a GenericRelatedObjectManager.
+    Added the try except.
+    '''
     obj_dict = obj.__dict__
     obj_dict_result = obj_dict.copy()
     for key, value in obj_dict.items():
@@ -31,7 +35,7 @@ def get_dict_from_obj(obj):
                 pass
     manytomany_list = obj._meta.many_to_many
     for manytomany in manytomany_list:
-        ids = [obj_rel.id for obj_rel in manytomany.value_from_object(obj)]
+        ids = [obj_rel.id for obj_rel in manytomany.value_from_object(obj).select_related()]
         if ids:
             obj_dict_result[manytomany.name] = ids
     return obj_dict_result
